Class: Date
- Inherits:
-
Object
- Object
- Date
- Defined in:
- lib/rcap/extensions/date.rb
Instance Method Summary collapse
-
#to_s_for_cap ⇒ String
Returns a string representaion of the time suitable for CAP.
Instance Method Details
#to_s_for_cap ⇒ String
Returns a string representaion of the time suitable for CAP.
8 9 10 |
# File 'lib/rcap/extensions/date.rb', line 8 def to_s_for_cap to_datetime.to_s_for_cap end |